@@ -20,6 +20,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <stdint.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <glib/gprintf.h>
@@ -331,7 +332,7 @@ jaw_impl_get_instance_from_jaw (JNIEnv *jniEnv, jobject ac)
   jclass classWrapper = (*jniEnv)->FindClass(jniEnv, "org/GNOME/Accessibility/AtkWrapper");
   jmethodID jmid = (*jniEnv)->GetStaticMethodID(jniEnv, classWrapper, "getInstanceFromSwing", "(Ljavax/accessibility/AccessibleContext;)J");
   jlong ptr = (*jniEnv)->CallStaticLongMethod(jniEnv, classWrapper, jmid, ac);
-  return (JawImpl*) ptr;
+  return (JawImpl*) (uintptr_t) ptr;
 }
 
 JawImpl*
@@ -567,7 +568,7 @@ jaw_impl_get_interface_data (JawObject *jaw_obj, guint iface)
   JAW_DEBUG_C("%p, %u", jaw_obj, iface);
   JawImpl *jaw_impl = (JawImpl*)jaw_obj;
 
-  if (jaw_impl->ifaceTable == NULL || jaw_impl == NULL)
+  if (jaw_impl == NULL || jaw_impl->ifaceTable == NULL)
     return NULL;
 
   JawInterfaceInfo *info = g_hash_table_lookup(jaw_impl->ifaceTable,GUINT_TO_POINTER(iface));
