@@ -410,7 +410,7 @@ jaw_util_get_atk_role_from_AccessibleContext (jobject jAccessibleContext)
     return ATK_ROLE_HTML_CONTAINER;
 
   if (jaw_util_is_java_acc_role(jniEnv, ac_role, "HYPERLINK"))
-    return ATK_ROLE_UNKNOWN;
+    return ATK_ROLE_LINK;
 
   if ( jaw_util_is_java_acc_role(jniEnv, ac_role, "ICON"))
     return ATK_ROLE_ICON;
@@ -548,7 +548,7 @@ jaw_util_get_atk_role_from_AccessibleContext (jobject jAccessibleContext)
   if ( jaw_util_is_java_acc_role(jniEnv, ac_role, "WINDOW"))
     return ATK_ROLE_WINDOW;
 
-  jmethodID jmideic = (*jniEnv)->GetMethodID(jniEnv, atkObject, "equalsIgnoreCaseLocaleWithRole", "(Ljavax/accessibility/AccessibleRole;)Z");
+  jmethodID jmideic = (*jniEnv)->GetStaticMethodID(jniEnv, atkObject, "equalsIgnoreCaseLocaleWithRole", "(Ljavax/accessibility/AccessibleRole;)Z");
   if ( (*jniEnv)->CallStaticBooleanMethod(jniEnv, atkObject, jmideic, ac_role) )
     return ATK_ROLE_PARAGRAPH;
 
@@ -589,7 +589,7 @@ jaw_util_get_atk_state_type_from_java_state (JNIEnv *jniEnv, jobject jobj)
     return ATK_STATE_CHECKED;
 
   if (is_same_java_state( jniEnv, jobj, "COLLAPSED" ))
-#ifdef ATK_STATE_COLLAPSED
+#if ATK_CHECK_VERSION (2,38,0)
     return ATK_STATE_COLLAPSED;
 #else
     return ATK_STATE_INVALID;
